@@ -72,7 +72,7 @@ mail_util_mapi_to_smtp_headers (E2kProperties *props)
 	GET_HEADER (E2K_PR_MAILHEADER_FROM, "From");
 	GET_HEADER (E2K_PR_MAILHEADER_TO, "To");
 	GET_HEADER (E2K_PR_MAILHEADER_CC, "Cc");
-	GET_HEADER (E2K_PR_MAILHEADER_MESSAGE_ID, "Message-Id");
+	GET_HEADER (E2K_PR_MAILHEADER_MESSAGE_ID, "Message-ID");
 	GET_HEADER (E2K_PR_MAILHEADER_IN_REPLY_TO, "In-Reply-To");
 	GET_HEADER (E2K_PR_MAILHEADER_REFERENCES, "References");
 	GET_HEADER (E2K_PR_MAILHEADER_THREAD_INDEX, "Thread-Index");
